@@ -1,3 +1,4 @@
+import os
 from pathlib import Path
 
 SSH_DIR = Path.home() / ".ssh/"
@@ -6,6 +7,8 @@ SSH_CONFIG_FILE = Path.home() / ".ssh/config"
 
 SSH_CONFIG_INCLUDE_DIRECTIVE = "Include config.d/*"
 
-WINDOWS_MULTIPASS_DEFAULT_ID_RSA = (
-    "C:/Windows/ProgramData/Multipass/data/ssh-keys/id_rsa"
-)
+_PROGRAM_DATA = Path(os.getenv("PROGRAMDATA", "C:\\ProgramData"))
+
+WINDOWS_MULTIPASS_DEFAULT_ID_RSA = Path(
+    _PROGRAM_DATA / Path("Multipass/data/ssh-keys/id_rsa")
+).as_posix()
