@@ -5,8 +5,8 @@ from local_ssh_config.utils.jinja._environment import JINJA_ENVIRONMENT
 
 def _create_file_from_template(
     template_name: str,
-    filename: Path,
     directory: Path,
+    filename: Path = None,
     variables: dict = {},
 ) -> None:
     """
@@ -14,7 +14,8 @@ def _create_file_from_template(
     by rendering the jinja template `template_name`
     """
     if filename is None:
-        filename = Path(template_name)
+        config_filename = template_name.replace(".j2", "")  # remove extension
+        filename = Path(config_filename)
 
     template = JINJA_ENVIRONMENT.get_template(f"{template_name}")
 
